#
# spec file for package inn
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           inn
BuildRequires:  bison
BuildRequires:  gdbm-devel
BuildRequires:  pam-devel
BuildRequires:  postfix
BuildRequires:  zlib-devel
Url:            http://www.isc.org/software/inn/
Summary:        InterNetNews
License:        GPL-2.0-or-later AND BSD-4-Clause
Group:          Productivity/Networking/News/Servers
Provides:       inn_pkg
Provides:       nntp_daemon
Conflicts:      cnews nntpd mininews
PreReq:         perl permissions
PreReq:         group(uucp)
PreReq:         user(news)
PreReq:         group(news)
Requires:       perl-MIME-tools
%{?systemd_requires}
%{?libperl_requires}
Version:        2.6.2
Release:        lp152.2.3.1
%define PatchVersion -%{version}
Source:         inn%{PatchVersion}.tar.gz
Source1:        doc-inn.tar.bz2
Source2:        pubring.pgp
Source3:        inn-emptydb.tar.gz
Source4:        inn.reg
Source5:        inn%{PatchVersion}.tar.gz.asc
Source6:        %{name}.keyring
Source7:        inn.service
Patch0:         inn-%{version}.diff
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#

%description
Rich Salz's InterNetNews news transport system.

%package devel
Requires:       %name = %version
Summary:        InterNetNews development files
Group:          Productivity/Networking/News/Servers

%description devel
Rich Salz's InterNetNews news transport system.

This package contains the files needed to develop software depending on
inn.

%package -n mininews
Summary:        Inews - Post News from an NNTP Client
Group:          Productivity/Networking/News/Utilities
Provides:       nntp_daemon
PreReq:         permissions
PreReq:         group(uucp)
PreReq:         user(news)
PreReq:         group(news)

%description -n mininews
Rich Salz's InterNetNews news transport system.

%prep
%setup -n inn%{PatchVersion} 
%setup -n inn%{PatchVersion} -D -T -a 1 
%setup -n inn%{PatchVersion} -D -T -a 3
%patch0
cp -a $RPM_SOURCE_DIR/pubring.pgp .

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
LDFLAGS="-pie" CFLAGS="$RPM_OPT_FLAGS -pipe -fno-strict-aliasing -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE -fPIE -fstack-protector" ./configure \
		--enable-dual-socket \
		--enable-uucp-rnews \
		--enable-setgid-inews \
		--prefix=/usr/lib/news \
		--sysconfdir=/etc/news \
		--mandir=%{_mandir} \
		--disable-shared \
		--enable-tagged-hash \
		--enable-ipv6 \
		--with-perl \
		--with-zlib \
		--with-sendmail=/usr/sbin/sendmail \
		--with-news-user=news \
		--with-news-group=news \
		--with-news-master=news \
		--with-etc-dir=/etc/news \
		--with-db-dir=/var/lib/news \
		--with-run-dir=/var/run/news \
		--with-log-dir=/var/log/news \
		--with-http-dir=/var/log/news/http \
		--with-spool-dir=/var/spool/news \
		--with-tmp-dir=/var/spool/news/tmp
make
cp site/inn.conf inn.conf.tmp
echo 'domain: test.com' >> inn.conf.tmp
echo "runasuser: $(id -n -u)" >> inn.conf.tmp
echo "runasgroup: $(id -n -g)" >> inn.conf.tmp
INNCONF=inn.conf.tmp expire/makedbz -f `pwd`/inn-emptydb/history -s 666666
rm -f inn.conf.tmp

%install
mkdir -p %{buildroot}/etc
mkdir -p %{buildroot}/usr/lib
mkdir -p %{buildroot}/usr/bin
mkdir -p %{buildroot}/var/lib
mkdir -p %{buildroot}/var/log
mkdir -p %{buildroot}/var/spool
mkdir -p %{buildroot}%{_mandir}
#
make DESTDIR=%{buildroot} OWNER= ROWNER= install
for i in %{buildroot}%{_mandir}/*/* ; do
  if test -L "$i" ; then
    il=$(readlink "$i")
    ln -s "$il.gz" "$i.gz"
    rm -f "$i"
  else
    gzip -nf9 "$i"
  fi
done
chmod 444 %{buildroot}/usr/lib/news/lib/*.a
# those just die("BerkeleyDB support not compiled");
rm %{buildroot}/usr/lib/news/bin/ovdb_server
rm %{buildroot}/usr/lib/news/bin/ovdb_stat
ln %{buildroot}/usr/lib/news/bin/ovdb_init %{buildroot}/usr/lib/news/bin/ovdb_server
ln %{buildroot}/usr/lib/news/bin/ovdb_init %{buildroot}/usr/lib/news/bin/ovdb_stat
#
#
# 
%define installnews install -o news -g news -m
%define installnews install -m
%define installroot install -o root -g root -m
%define installroot install -m
%{installnews} 0755 	-d		%{buildroot}/var/log/news/http
%{installnews} 0644	subscriptions	%{buildroot}/etc/news
%{installnews} 0644	distributions	%{buildroot}/etc/news
%{installnews} 0644	crontab.sample	%{buildroot}/etc/news
%{installnews} 0644	profile		%{buildroot}/etc/news/.profile
%{installnews} 0755 	-d		%{buildroot}/etc/news/.pgp
%{installnews} 0600	pubring.pgp	%{buildroot}/etc/news/.pgp
%{installnews} 0644	samples/send-uucp.cf	%{buildroot}/etc/news
%{installnews} 0755 	-d		%{buildroot}/var/log/news/http
%{installnews} 0755 	-d		%{buildroot}/var/log/news/http/pics
%{installnews} 0555	convertspool	%{buildroot}/usr/lib/news/bin
%{installnews} 0755 	-d		%{buildroot}/usr/lib/news/include
%{installnews} 0755 	-d		%{buildroot}/usr/lib/news/include/inn
#%{installnews} 0644	include/clibrary.h	%{buildroot}/usr/lib/news/include
#%{installnews} 0644	include/config.h	%{buildroot}/usr/lib/news/include
#
# 
#
%{installnews} 0644	inn-emptydb/*	%{buildroot}/var/lib/news
%{installnews} 0755 	-d		%{buildroot}/var/lib/news/backoff
#
# compat links
#
ln -sf bin/inews		%{buildroot}/usr/lib/news/inews
ln -sf ../lib/news/bin/inews	%{buildroot}/usr/bin/inews
ln -sf ../lib/news/bin/rnews	%{buildroot}/usr/bin/rnews
#
# other links
#
ln -sf ../innfeed.status	%{buildroot}/var/log/news/http/innfeed.status.txt
ln -sf ../inn.status		%{buildroot}/var/log/news/http/inn.status.txt
#
# 
# 
%{installnews} 0755	-d		%{buildroot}/usr/lib/systemd/system
%{installroot} 0644	%{SOURCE7}	%{buildroot}/usr/lib/systemd/system/inn.service
%{installnews} 0755	-d		%{buildroot}/usr/sbin
ln -sf service 	%{buildroot}/usr/sbin/rcinn
#
touch				%{buildroot}/var/log/news/news
touch				%{buildroot}/var/log/news/news.notice
touch				%{buildroot}/var/log/news/news.err
touch				%{buildroot}/var/log/news/news.crit
touch				%{buildroot}/var/log/news/inn.status
touch				%{buildroot}/var/log/news/innfeed.status
#
# SLP regfile
#
%{installroot} 0755	-d		%{buildroot}/etc/slp.reg.d
%{installroot} 0644	%{SOURCE4}	%{buildroot}/etc/slp.reg.d/
# /var/run/news
mkdir -p $RPM_BUILD_ROOT/usr/lib/tmpfiles.d/
echo "d /var/run/news 0750 news news -" > %{buildroot}/usr/lib/tmpfiles.d/inn.conf

#
# build filelist
# 
%define filelist %{name}-filelist
find %{buildroot} -type d -printf "/%%P\n" | awk '
! /^\/(etc|usr\/lib|var\/lib|var\/log|var\/spool|var\/run)\/news/ { next }
$0 == "/etc/news"     { next }
$0 == "/usr/lib/news/include" { next }
$0 == "/usr/lib/news/include/inn" { next }
$0 == "/var/run/news" { next }
{ pfx="" }
$0 == "/usr/lib/news" { pfx = "%%attr(755,root,root) " }
$0 == "/var/lib/news" { pfx = "%%attr(755,news,news) " }
$0 == "/usr/lib/news/bin" { pfx = "%%attr(755,root,root) " }
$0 == "/var/spool/news" { pfx = "%%attr(775,news,news) " }
$0 == "/var/run/news" { pfx = "%ghost %%attr(750,news,news) "}
/\/usr\/lib\/news/ {
	if (!match(pfx, /%%attr/)) pfx = "%%attr(755,root,root) " pfx
}
/\/news/ {
 	if (!match(pfx, /%%attr/)) pfx = "%%attr(-,news,news) " pfx
}
{ print "%dir " pfx $0 }
' > %{filelist}
find %{buildroot} ! -type d -printf "/%%P\n" | awk '
{ pfx="" }
/^\/usr\/lib\/news\/include/              { next }
/^\/usr\/lib\/news\/lib\/.*\.a/             { next }
$0 == "/usr/lib/news/bin/inews"           { pfx="%attr(2555,news,news) " }
$0 == "/usr/lib/news/bin/rnews"           { pfx="%attr(4550,news,uucp) " }
$0 == "/usr/lib/news/bin/innbind"         { pfx="%verify(not mode) %attr(4550,root,news) " }
/^\/(etc\/news|usr\/lib\/news\/bin\/filter|var\/lib\/news)\// {
	pfx="%config(noreplace) "pfx
}
/\/man\/man/ {
	pfx="%doc %attr(444,root,root) "pfx
}
/^\/var\/log\/news\/(news|inn\.status|innfeed\.status)/ {
	pfx="%ghost %attr(644,news,news) "pfx
}
/\/usr\/lib\/news/ {
	if (!match(pfx, /%%attr/)) pfx = "%%attr(-,root,news) " pfx
}
/\/news\// {
 	if (!match(pfx, /%%attr/)) pfx = "%%attr(-,news,news) " pfx
}
/^\/etc\/slp\.reg\.d\// { next }
{ print pfx $0 }
' >> %{filelist}
#
# 
# 

%pre
test -f var/log/news && mv var/log/news var/log/news.bak
%service_add_pre inn.service
exit 0

%post
runuser -u news -g news touch \
    var/log/news/news.notice \
    var/log/news/news.err \
    var/log/news/news.crit \
    var/log/news/news \
    var/log/news/inn.status \
    var/log/news/innfeed.status
if test -e usr/lib/news/bin/control/version -o -e usr/lib/news/bin/inndstart ; then
    rm -f etc/news/inn.conf.OLD
    rm -f etc/news/newsfeeds.OLD
    usr/lib/news/bin/innupgrade etc/news
fi
if ! test -d /var/run/news ; then
    install -d -m 750 -o news -g news /var/run/news
fi
%set_permissions /usr/lib/news/bin/innbind /usr/lib/news/bin/inews /usr/lib/news/bin/rnews
%service_add_post inn.service

%post -n mininews
if [ -x /usr/bin/systemd-tmpfiles ]; then
    /usr/bin/systemd-tmpfiles --create inn.conf
fi
%set_permissions /usr/lib/news/bin/inews /usr/lib/news/bin/rnews

%verifyscript
%verify_permissions -e /usr/lib/news/bin/innbind -e /usr/lib/news/bin/inews -e /usr/lib/news/bin/rnews

%verifyscript -n mininews
%verify_permissions -e /usr/lib/news/bin/inews -e /usr/lib/news/bin/rnews

%preun
%service_del_preun inn.service

%postun
%service_del_postun inn.service

%files -f %{filelist}
%defattr(-,root,root)
%dir			/etc/slp.reg.d
%config(noreplace)	/etc/slp.reg.d/inn.reg
%doc ChangeLog NEWS INSTALL README*
%doc doc-inn/*

%files devel
%defattr(-,root,root)
/usr/lib/news/include
/usr/lib/news/lib/*.a

%files -n mininews
%defattr(-,root,root)
%config(noreplace)      /etc/news/inn.conf
%dir                    /usr/lib/news/bin
%attr(4550,news,uucp)   /usr/lib/news/bin/rnews
%attr(2555,news,news)   /usr/lib/news/bin/inews
                        /usr/bin/[ri]news
                        /usr/lib/news/[ri]news
%doc                    %{_mandir}/*/inn.conf.*
%doc                    %{_mandir}/*/[ri]news.*

%changelog
* Fri Jul 24 2020 mls@suse.de
- change file owners in /usr/lib/news to root
  [bnc#1172573] [CVE-2020-8026]
* Fri Jan 24 2020 mls@suse.de
- change user to news before touching files in /var/log/news
  [bnc#1154302] [CVE-2019-3692]
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Fri Dec 14 2018 mls@suse.de
- update to inn-2.6.2
  * support for compressed newsfeeds
  * many bug fixes and documentation improvements
  * dropped patch: inn-2.5.4.diff
  * new patch: inn-2.6.2.diff
- use native systemd service [#1116017]
  * new file: inn.service
* Tue Feb 21 2017 kukuk@suse.de
- Add directories formerly owned by filesystem
- Require group and user news
- Require group uucp
* Wed Oct 26 2016 kukuk@suse.de
- Fix tmpfiles.d usage to give it at least a chance to work
* Sat Dec 13 2014 Led <ledest@gmail.com>
- fix bashisms
- updated patches:
  + inn-2.5.4.diff
* Thu Dec 11 2014 mls@suse.de
- enable IPv6
- get rid of gpg-offline as we nowadays check signatures in
  the source validator
* Wed Jul 16 2014 mls@suse.de
- update to inn-2.5.4
  * updated control.ctl file
  * improved signature checking in pgpverify
  * new "htmlstatus" config option
  * many bugs fixed
  * removed patches: inn-linereset.diff
  * renamed patches: inn-2.5.2.diff -> inn-2.5.4.diff
- fix innbind file mode
- fix empty history database on 64bit [bnc#876287]
* Mon Sep  9 2013 mls@suse.de
- make /usr/lib/news/bin owned by root
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Tue Nov 27 2012 sbrabec@suse.cz
- Verify GPG signature.
* Mon Sep 17 2012 coolo@suse.com
- fix ownership of directories so subpackages can be installed with
  rpm 4.10
* Tue Sep  4 2012 mls@suse.de
- fix starttls command injection issue [bnc#776967]
- fix /var/run/news permission and handling.
* Tue Jun 19 2012 aj@suse.de
- Use set_permissions instead of run_permissions.
- Handle /var/run on tmpfs.
* Thu Mar 22 2012 cfarrell@suse.com
- license update: GPL-2.0+ and BSD-4-Clause
  SPDX format and also include *.in files from control/ as BSD-4-Clause
* Fri Mar 16 2012 lmuelle@suse.de
- require perl-MIME-tools
* Wed May 19 2010 mls@suse.de
- adapt innbind modes to permissions file
* Thu Apr  8 2010 mls@suse.de
- compile with largefile support
* Wed Apr  7 2010 mls@suse.de
- update to inn-2.5.2
  * implement CAPABILITIES command
  * decent parser for NNTP commands
  * multiple LIST commands allow pattern matching
* Fri Sep  4 2009 mls@suse.de
- fix fd leak [bnc#525827]
* Sun Aug 30 2009 coolo@novell.com
- provide Patch0
* Thu Jul 10 2008 mls@suse.de
- fix segfault in perl_call_argv [bnc#405186]
* Thu Jun 19 2008 werner@suse.de
- Add missing Provides to the init script
* Wed May 30 2007 mls@suse.de
- split devel package
- remove some file duplicates
* Mon Apr  2 2007 rguenther@suse.de
- Add gdbm-devel BuildRequires.
* Thu Mar 29 2007 rguenther@suse.de
- Add bison BuildRequires.
* Wed Feb 14 2007 schwab@suse.de
- Fix building as non-root.
* Mon Nov 13 2006 mls@suse.de
- initialize mechusing variable to shut up intel compiler [#197713]
* Mon Jan 30 2006 mls@suse.de
- add -fstack-protector to CFLAGS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jun 27 2005 ro@suse.de
- build with fPIE/pie
* Fri Mar 11 2005 mls@suse.de
- fix off-by-one error in parsedate_rfc2822
* Fri Mar  4 2005 mls@suse.de
- package startinnfeed with mode 4755
* Fri Feb  4 2005 mls@suse.de
- update to inn-2.4.2
* Thu Nov 11 2004 ro@suse.de
- permissions handling fix
* Sun Apr  4 2004 mls@suse.de
- made /usr/lib/news/bin owned by root:root as it contains
  a suid-root program
* Fri Mar 26 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Thu Mar 18 2004 mls@suse.de
- provide slp regfile
- pack manpages with owner root:root
* Fri Feb 27 2004 mls@suse.de
- update to inn-2.4.1
- updated inn faq
* Fri Jan 16 2004 kukuk@suse.de
- Cleanup neededforbuild
* Mon Jan 12 2004 adrian@suse.de
- package startinnfeed with 0555 permissions
  (following permissions scripts)
* Fri Jan  9 2004 thomas@suse.de
- fixed remotely exploitable buffer overflow (#33882)
* Tue Sep  2 2003 mls@suse.de
- use stop_on_removal/restart_on_update macros
- convertspool: use split -a 5
* Wed Jul 30 2003 mls@suse.de
- update to inn-2.4.0
* Mon Jun 23 2003 mls@suse.de
- create link targets as ghost
- don't pack /etc/news, /usr/lib/news, /var/lib/news, they
  are already in filesystem.rpm
* Fri Apr 11 2003 ro@suse.de
- fix deprecated head/tail calling syntax (-1)
* Mon Mar  3 2003 mls@suse.de
- touch /var/log/news/news in postinstall (#24555)
* Fri Jan 10 2003 mls@suse.de
- update to inn-2.3.4
* Wed Sep 11 2002 mls@suse.de
- corrected Required-Start in rc file (#19402)
* Tue Aug 20 2002 mls@suse.de
- added PreReqs
- dropped superfluous (and dangerous) "Provides: inn"
* Fri Aug  9 2002 mls@suse.de
- made it work with threaded perl-5.8.0
* Fri Jul 12 2002 mls@suse.de
- fixed postinstall script to be sh -e resistant
- check if compress binary really works in uucp scripts
* Tue Jul  2 2002 meissner@suse.de
- rerun auto* tools.
* Thu May  2 2002 mls@suse.de
- use gzip if compress is not available (bug #15793)
- make inn header files available, suck needs them
* Thu Apr  4 2002 mls@suse.de
- fix LIBOBJS in configure.in for new autoconf version
* Wed Mar  6 2002 mls@suse.de
- put innd in xrefslave mode in convertspool script
- fix innconfval segfault if pathhost is not set
* Mon Feb 25 2002 mls@suse.de
- fixed permissions of inn libraries
- added comment about overchan and controlchan
* Thu Feb 14 2002 mls@suse.de
- added detection of old history format to rc.news
- added convertspool script
- updated README.linux
- use "rc.news stop" to stop inn
* Mon Feb 11 2002 mls@suse.de
- update to inn-2.3.2.
- rcinn now LSB compliant.
* Tue Jan 15 2002 ro@suse.de
- removed START_INN
* Tue Jan 15 2002 egmont@suselinux.hu
- Removed colons from startup/shutdown messages.
* Wed Jun 13 2001 schwab@suse.de
- Fix for new autoconf.
* Tue Mar 13 2001 ma@suse.de
- Explicitly set permissions for inews(sgid news), rnews(suid news),
  inndstart and startinnfeed (both suid root) in specfile.
* Mon Dec  4 2000 ma@suse.de
- adopt LSB runlevel and init script scheme
* Thu Nov 23 2000 ma@suse.de
- IPv6 patch removed
* Fri Oct 13 2000 ma@suse.de
- Update to inn-2.2.3
- IPv6 patch form http://bofh.st/ipv6/downloads/sith.mimuw.edu.pl
  added.
* Wed Sep  6 2000 ma@suse.de
- fixed restart, status and reload section in rcinn (#3889)
* Thu Jul 27 2000 ma@suse.de
- fixed wrong ownership of ~news
* Thu Jul  6 2000 ma@suse.de
- fixed wrong pathnames in send-uucp.pl
* Mon Jun 19 2000 ma@suse.de
- fixes some possible on-stack buffer overflows
- using BuildRoot
- add directories for control, control.cancel and junk (#2644)
- article filters marked as config (#1760)
* Fri Mar 31 2000 schwab@suse.de
- Update config.{guess,sub} from automake.
* Thu Mar  2 2000 ro@suse.de
- use %%{_mandir}
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Wed Jan 12 2000 ma@suse.de
- update to 2.2.2 STABLE snapshot 2000-10-01.
  Y2K bugs fixed
- added rnews to mininews subpackage
* Wed Nov 24 1999 ma@suse.de
- update to 2.2.1 STABLE snapshot 1999-11-23.
  fixes some bugs that cause inn to crash.
* Mon Sep 20 1999 ro@suse.de
- added Provides nntp_daemon for mininews
* Mon Sep 20 1999 ro@suse.de
- added Provides nntp_daemon
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug 30 1999 ma@suse.de
- update to 2.2.1 (Fixes for possible buffer overflow)
* Tue Jan 19 1999 uli@suse.de
- update to newer inn sources
- do not have an open inn server as default configuration
* Tue Jan 19 1999 uli@suse.de
- mininews: fixed missing binary, added /etc/news/inn.conf
* Fri Jan  8 1999 florian@suse.de
- add the FAQ again
- add /usr/sbin/rcinn
* Thu Dec 17 1998 florian@suse.de
- update to current cvs-version
- fix innfeed.conf to use "inn.feed" directory
* Fri Dec 11 1998 ro@suse.de
- update to 2.2
* Sat Nov 14 1998 ro@suse.de
- fix type-conflict for mmap in include/clibrary.h
- build mininews from same specfile
* Sun Sep 20 1998 ro@suse.de
- dont redeclare sys_errlist for glibc
- change return value of exit in include/clibrary.h to explicit "void"
- add -lcrypt for glibc
* Fri Oct 24 1997 florian@suse.de
- rework autobuild support
- update to inn 1.7
* Tue Oct 21 1997 ro@suse.de
- ready for autobuild
* Mon Jun  2 1997 florian@suse.de
- mv fillup to /var/adm/fillup-templates/
- include correct postinstall script
* Tue May 27 1997 florian@suse.de
- always use gzip to decompress news-batches
* Thu Apr 10 1997 florian@suse.de
- all log files are in /var/lib/news/log
- inn doesn't try to look at syslog files
- pgp-verification is ready to be used
- all known security patches and some bug-reports installed
- new faq files and docu cleanup
